## intent:greet
- Здравствуйте.
- Привет!
- Хай.
- Здрасте.
- Здоро́во!
- Здравствуйте.
- Привет!
- Алло!

## intent:farewell
- Пока
- Попрощайся.
- Попрощайтесь.
- Скажи "до свидания".
- Скажите "до свидания".

## intent:affirm
- Сделай это.
- Продолжай.
- Продолжайте.
- Я знаю.
- Знамо дело.
- Знаю.
- Со мной всё в порядке.
- У меня всё хорошо.
- У меня всё в порядке.

## intent:deny
- Я увольняюсь.
- Не может быть!
- Это невозможно!
- Никогда в жизни!
- Быть не может!
- Это исключено!
- Ни в коем случае!
- Ни в коем случае.
- Ни за что!

## intent:stop
- Спокойно!
- Будь спокоен.
- Будь спокойна.
- Будьте спокойны.
- Не ходи.
- Не ходите.
- Не езди.
- Не ездите.

## intent:thank
- Со мной всё в порядке.
- Я в порядке.
- Спасибо.
- Спасибо тебе.

## intent:help
- Помогите!
- На помощь!
- Спасите!

## intent:wait
- Подожди!
- Подождите!
- Ждите!
- Жди!
- Ждите.
